package com.zehong.system.service.impl.track;

import java.util.Date;
import java.util.List;
import com.zehong.common.utils.DateUtils;
import com.zehong.common.utils.SecurityUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.zehong.system.mapper.TProductInspectDetailMapper;
import com.zehong.system.domain.track.TProductInspectDetail;
import com.zehong.system.service.track.ITProductInspectDetailService;

/**
 * 生产执行中间Service业务层处理
 * 
 * @author zehong
 * @date 2024-08-26
 */
@Service
public class TProductInspectDetailServiceImpl implements ITProductInspectDetailService 
{
    @Autowired
    private TProductInspectDetailMapper tProductInspectDetailMapper;

    /**
     * 查询生产执行中间
     * 
     * @param id 生产执行中间ID
     * @return 生产执行中间
     */
    @Override
    public TProductInspectDetail selectTProductInspectDetailById(Long id)
    {
        return tProductInspectDetailMapper.selectTProductInspectDetailById(id);
    }

    /**
     * 查询生产执行中间列表
     * 
     * @param tProductInspectDetail 生产执行中间
     * @return 生产执行中间
     */
    @Override
    public List<TProductInspectDetail> selectTProductInspectDetailList(TProductInspectDetail tProductInspectDetail)
    {
        return tProductInspectDetailMapper.selectTProductInspectDetailList(tProductInspectDetail);
    }

    /**
     * 新增生产执行中间
     * 
     * @param tProductInspectDetail 生产执行中间
     * @return 结果
     */
    @Override
    public int insertTProductInspectDetail(TProductInspectDetail tProductInspectDetail)
    {
        tProductInspectDetail.setCreateTime(DateUtils.getNowDate());
        tProductInspectDetail.setCreateId(SecurityUtils.getLoginUser().getUser().getUserId());
        return tProductInspectDetailMapper.insertTProductInspectDetail(tProductInspectDetail);
    }

    /**
     * 修改生产执行中间
     * 
     * @param tProductInspectDetail 生产执行中间
     * @return 结果
     */
    @Override
    public int updateTProductInspectDetail(TProductInspectDetail tProductInspectDetail)
    {
        return tProductInspectDetailMapper.updateTProductInspectDetail(tProductInspectDetail);
    }

    /**
     * 批量删除生产执行中间
     * 
     * @param ids 需要删除的生产执行中间ID
     * @return 结果
     */
    @Override
    public int deleteTProductInspectDetailByIds(Long[] ids)
    {
        return tProductInspectDetailMapper.deleteTProductInspectDetailByIds(ids);
    }

    /**
     * 删除生产执行中间信息
     * 
     * @param id 生产执行中间ID
     * @return 结果
     */
    @Override
    public int deleteTProductInspectDetailById(Long id)
    {
        return tProductInspectDetailMapper.deleteTProductInspectDetailById(id);
    }

    /**
     * 批量新增详情
     * @param productInspectDetailList
     * @return
     */
    public int batchAddDetailInfo(List<TProductInspectDetail> productInspectDetailList){
        for(TProductInspectDetail detail : productInspectDetailList){
            detail.setCreateTime(new Date());
            detail.setCreateId(SecurityUtils.getLoginUser().getUser().getUserId());
        }
        return tProductInspectDetailMapper.batchAddDetailInfo(productInspectDetailList);
    }
}
